[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- pilas.pytweener.Easing.Back
- pilas.pytweener.Easing.Bounce
- pilas.pytweener.Easing.Circ
- pilas.colisiones.Colisiones: Administra todas las colisiones entre actores.
- pilas.fisica.ConstanteDeDistancia: Representa una distancia fija entre dos figuras.
- pilas.fisica.ConstanteDeMovimiento: Representa una constante de movimiento para el mouse.
- pilas.pytweener.Easing.Cubic
- pilas.actores.dialogo.Dialogo: Representa una secuencia de mensajes entre varios actores.
- pilas.pytweener.Easing
- pilas.pytweener.Easing.Elastic
- pilas.estudiante.Estudiante: Componente que permite a los actores aprender habilidades o realizar comportamientos.
  - pilas.actores.actor.Actor: Representa un objeto visible en pantalla, algo que se ve y tiene posicion.
    - pilas.actores.aceituna.Aceituna: Representa una Aceituna.
    - pilas.actores.animado.Animado: Representa un actor que tiene asociada una grilla con cuadros de animacion.
      - pilas.actores.animacion.Animacion: Representa una animacion de una grilla de imagenes.
        - pilas.actores.bomba.Bomba: Representa una bomba que puede explotar...
        - pilas.actores.proyectil.Dinamita: Representa un cartucho de dinamita.
        - pilas.actores.explosion.Explosion: Representa una explosion para una bomba, dinamita etc...
        - pilas.actores.humo.Humo: Muestra una animación de una nube de humo.
        - pilas.actores.proyectil.Misil: Representa un misil que va en línea recta con aceleración.
        - pilas.actores.moneda.Moneda: Representa una moneda con animación.
        - pilas.actores.nave.Nave: Representa una nave que puede disparar.
        - pilas.actores.navekids.NaveKids: Representa una nave de aspecto infantil que puede disparar.
      - pilas.demos.piezas.Pieza: Representa una pieza del rompecabezas.
    - pilas.actores.proyectil.Bala: Representa una bala que va en línea recta.
    - pilas.actores.banana.Banana: Muestra una banana que se combina (temáticamente) con el actor Mono.
    - pilas.interfaz.base_interfaz.BaseInterfaz: Representa un actor que actuará como un elemento de interfaz de usuario.
      - pilas.interfaz.boton.Boton: Representa un botón que se puede pulsar y disparar una acción.
      - pilas.interfaz.deslizador.Deslizador: Representa un deslizador (slider) tipo volumen horizontal.
      - pilas.interfaz.ingreso_de_texto.IngresoDeTexto: Representa una caja de texto para escribir sobre ella.
      - pilas.interfaz.lista_seleccion.ListaSeleccion
      - pilas.interfaz.selector.Selector: Representa un selector con un checkbox.
    - pilas.actores.personajes_rpg.BasePersonajeRPG: Representa un personaje de juego tipo RPG.
      - pilas.actores.personajes_rpg.Calvo: Representa un personaje de juego tipo RPG.
      - pilas.actores.personajes_rpg.Maton: Representa un personaje de juego tipo RPG.
    - pilas.actores.boton.Boton: Representa un boton que reacciona al ser presionado.
      - pilas.actores.sonido.Sonido: Un icono de sonido en la parte inferior derecha de la pantalla.
    - pilas.actores.caja.Caja: Representa una caja que posee fisica.
    - pilas.actores.cooperativista.Cooperativista: Representa un Cooperativista que puede caminar y trabajar.
    - pilas.actores.cursordisparo.CursorDisparo: Representa un cursor con una cruz roja.
    - pilas.actores.mano.CursorMano: Representa un cusor del raton en forma de mano.
    - pilas.actores.ejes.Ejes: Representa el eje de coordenadas tomado como sistema de referencia.
    - pilas.actores.energia.Energia: Representa un indicador de energia (en forma de barra horizontal).
    - pilas.actores.estrella.Estrella: Representa una estrella de color amarillo.
    - pilas.actores.proyectil.EstrellaNinja: Representa una estrella ninja.
    - pilas.actores.fantasma.Fantasma: Muestra un fantasma similar al del juego Pac-Man
    - pilas.fondos.Fondo
      - pilas.fondos.Color: Pinta todo el fondo de un color uniforme.
      - pilas.fondos.Desplazamiento: Representa un fondo formado por varias capas (o actores).
      - pilas.fondos.Espacio: Es un espacio con estrellas.
      - pilas.fondos.Noche: Muestra una escena que tiene un fondo de pantalla de paisaje.
      - pilas.fondos.Nubes: Muestra un fondo celeste con nubes.
      - pilas.fondos.Pasto: Muestra una escena que tiene un fondo de pantalla de paisaje.
      - pilas.fondos.Plano
      - pilas.fondos.Selva: Muestra una escena que tiene un fondo de pantalla de paisaje.
      - pilas.fondos.Tarde: Representa una escena de fondo casi naranja.
      - pilas.fondos.Volley: Muestra una escena que tiene un fondo de pantalla de paisaje.
    - pilas.actores.globo.Globo: Representa un cuadro de dialogo estilo historietas.
      - pilas.actores.globoelegir.GloboElegir: Representa un mensaje de globo (similar a las historietas), pero con opciones para elegir.
    - pilas.actores.mapa.Mapa: Representa una mapa de bloques rectangulares, ideal para crear escenarios de plataformas y mapas.
      - pilas.actores.mapatiled.MapaTiled: Representa mapas creados a partir de imagenes mas pequeñas.
    - pilas.actores.martian.Martian: Es un personaje de un marciano que puede caminar, saltar y disparar.
    - pilas.actores.menu.Menu: Un actor que puede mostrar una lista de opciones a seleccionar.
    - pilas.actores.mono.Mono: Representa la cara de un mono de color marrón.
    - pilas.actores.ovni.Ovni: Representa Ovni que explota al momento de ser eliminado.
    - pilas.actores.pacman.Pacman: Muestra un personaje similar al juego Pac-Man
    - pilas.actores.pausa.Pausa: Representa un ícono que se mostrará cuando el juego esté en pausa.
    - pilas.actores.pelota.Pelota: Representa una pelota de Volley, que puede rebotar e interactuar con la física del escenario.
    - pilas.actores.piedra.Piedra: Representa una piedra que podría ser usada como meteoríto.
    - pilas.actores.pingu.Pingu: Muestra a un pingüino que sabe caminar con el teclado.
    - pilas.actores.pizarra.Pizarra: Representa una superficie de dibujo inicialmente transparente.
    - pilas.actores.ovni.Planeta: Representa un planeta para utilizar con el ovni.
    - pilas.actores.texto.Texto: Representa un texto en pantalla.
      - pilas.actores.opcion.Opcion: Un item discreto, dispara una funcion al seleccionares.
      - pilas.actores.puntaje.Puntaje: Representa un contador de Puntaje
      - pilas.actores.temporizador.Temporizador: Representa un contador de tiempo con cuenta regresiva.
      - pilas.actores.texto_inferior.TextoInferior: Representa un texto al pie de la ventana.
    - pilas.actores.torreta.Torreta: Representa una torreta que puede disparar y rota con el mouse.
    - pilas.actores.tortuga.Tortuga: Representa una tortuga que se puede mover por la pantalla.
    - pilas.actores.zanahoria.Zanahoria: Representa un actor que parece una Zanahoria.
- pilas.evento.Evento
- pilas.pytweener.Easing.Expo
- pilas.pytweener.Easing.Linear
- PyQt4.QtGui.QDialog
- PyQt4.QtGui.QMainWindow
- PyQt4.QtGui.QMainWindow
- PyQt4.QtGui.QMainWindow
- PyQt4.QtGui.QSyntaxHighlighter
- PyQt4.QtGui.QWidget
- pilas.pytweener.Easing.Quad
- pilas.pytweener.Easing.Quart
- pilas.pytweener.Easing.Quint
- pilas.pytweener.Easing.Sine
- pilas.motores.motor_qt.SonidoDeshabilitado
- pilas.motores.motor_qt.SonidoGST
- pilas.motores.motor_qt.SonidoPhonon
- pilas.pytweener.Easing.Strong
- pilas.fisica.Tmp
  - pilas.fisica.ObjetosContactListener: Gestiona las colisiones de los objetos para ejecutar funcionés.
- pilas.pytweener.TweenTestObject
- pilas.pytweener.Tweenable
- pilas.actores.mapatiled.XmlNode: Representa un nodo XML.
- object: The most base type
  - pilas.actores.actor.Actor: Representa un objeto visible en pantalla, algo que se ve y tiene posicion.
    - pilas.actores.aceituna.Aceituna: Representa una Aceituna.
    - pilas.actores.animado.Animado: Representa un actor que tiene asociada una grilla con cuadros de animacion.
      - pilas.actores.animacion.Animacion: Representa una animacion de una grilla de imagenes.
        - pilas.actores.bomba.Bomba: Representa una bomba que puede explotar...
        - pilas.actores.proyectil.Dinamita: Representa un cartucho de dinamita.
        - pilas.actores.explosion.Explosion: Representa una explosion para una bomba, dinamita etc...
        - pilas.actores.humo.Humo: Muestra una animación de una nube de humo.
        - pilas.actores.proyectil.Misil: Representa un misil que va en línea recta con aceleración.
        - pilas.actores.moneda.Moneda: Representa una moneda con animación.
        - pilas.actores.nave.Nave: Representa una nave que puede disparar.
        - pilas.actores.navekids.NaveKids: Representa una nave de aspecto infantil que puede disparar.
      - pilas.demos.piezas.Pieza: Representa una pieza del rompecabezas.
    - pilas.actores.proyectil.Bala: Representa una bala que va en línea recta.
    - pilas.actores.banana.Banana: Muestra una banana que se combina (temáticamente) con el actor Mono.
    - pilas.interfaz.base_interfaz.BaseInterfaz: Representa un actor que actuará como un elemento de interfaz de usuario.
      - pilas.interfaz.boton.Boton: Representa un botón que se puede pulsar y disparar una acción.
      - pilas.interfaz.deslizador.Deslizador: Representa un deslizador (slider) tipo volumen horizontal.
      - pilas.interfaz.ingreso_de_texto.IngresoDeTexto: Representa una caja de texto para escribir sobre ella.
      - pilas.interfaz.lista_seleccion.ListaSeleccion
      - pilas.interfaz.selector.Selector: Representa un selector con un checkbox.
    - pilas.actores.personajes_rpg.BasePersonajeRPG: Representa un personaje de juego tipo RPG.
      - pilas.actores.personajes_rpg.Calvo: Representa un personaje de juego tipo RPG.
      - pilas.actores.personajes_rpg.Maton: Representa un personaje de juego tipo RPG.
    - pilas.actores.boton.Boton: Representa un boton que reacciona al ser presionado.
      - pilas.actores.sonido.Sonido: Un icono de sonido en la parte inferior derecha de la pantalla.
    - pilas.actores.caja.Caja: Representa una caja que posee fisica.
    - pilas.actores.cooperativista.Cooperativista: Representa un Cooperativista que puede caminar y trabajar.
    - pilas.actores.cursordisparo.CursorDisparo: Representa un cursor con una cruz roja.
    - pilas.actores.mano.CursorMano: Representa un cusor del raton en forma de mano.
    - pilas.actores.ejes.Ejes: Representa el eje de coordenadas tomado como sistema de referencia.
    - pilas.actores.energia.Energia: Representa un indicador de energia (en forma de barra horizontal).
    - pilas.actores.estrella.Estrella: Representa una estrella de color amarillo.
    - pilas.actores.proyectil.EstrellaNinja: Representa una estrella ninja.
    - pilas.actores.fantasma.Fantasma: Muestra un fantasma similar al del juego Pac-Man
    - pilas.fondos.Fondo
      - pilas.fondos.Color: Pinta todo el fondo de un color uniforme.
      - pilas.fondos.Desplazamiento: Representa un fondo formado por varias capas (o actores).
      - pilas.fondos.Espacio: Es un espacio con estrellas.
      - pilas.fondos.Noche: Muestra una escena que tiene un fondo de pantalla de paisaje.
      - pilas.fondos.Nubes: Muestra un fondo celeste con nubes.
      - pilas.fondos.Pasto: Muestra una escena que tiene un fondo de pantalla de paisaje.
      - pilas.fondos.Plano
      - pilas.fondos.Selva: Muestra una escena que tiene un fondo de pantalla de paisaje.
      - pilas.fondos.Tarde: Representa una escena de fondo casi naranja.
      - pilas.fondos.Volley: Muestra una escena que tiene un fondo de pantalla de paisaje.
    - pilas.actores.globo.Globo: Representa un cuadro de dialogo estilo historietas.
      - pilas.actores.globoelegir.GloboElegir: Representa un mensaje de globo (similar a las historietas), pero con opciones para elegir.
    - pilas.actores.mapa.Mapa: Representa una mapa de bloques rectangulares, ideal para crear escenarios de plataformas y mapas.
      - pilas.actores.mapatiled.MapaTiled: Representa mapas creados a partir de imagenes mas pequeñas.
    - pilas.actores.martian.Martian: Es un personaje de un marciano que puede caminar, saltar y disparar.
    - pilas.actores.menu.Menu: Un actor que puede mostrar una lista de opciones a seleccionar.
    - pilas.actores.mono.Mono: Representa la cara de un mono de color marrón.
    - pilas.actores.ovni.Ovni: Representa Ovni que explota al momento de ser eliminado.
    - pilas.actores.pacman.Pacman: Muestra un personaje similar al juego Pac-Man
    - pilas.actores.pausa.Pausa: Representa un ícono que se mostrará cuando el juego esté en pausa.
    - pilas.actores.pelota.Pelota: Representa una pelota de Volley, que puede rebotar e interactuar con la física del escenario.
    - pilas.actores.piedra.Piedra: Representa una piedra que podría ser usada como meteoríto.
    - pilas.actores.pingu.Pingu: Muestra a un pingüino que sabe caminar con el teclado.
    - pilas.actores.pizarra.Pizarra: Representa una superficie de dibujo inicialmente transparente.
    - pilas.actores.ovni.Planeta: Representa un planeta para utilizar con el ovni.
    - pilas.actores.texto.Texto: Representa un texto en pantalla.
      - pilas.actores.opcion.Opcion: Un item discreto, dispara una funcion al seleccionares.
      - pilas.actores.puntaje.Puntaje: Representa un contador de Puntaje
      - pilas.actores.temporizador.Temporizador: Representa un contador de tiempo con cuenta regresiva.
      - pilas.actores.texto_inferior.TextoInferior: Representa un texto al pie de la ventana.
    - pilas.actores.torreta.Torreta: Representa una torreta que puede disparar y rota con el mouse.
    - pilas.actores.tortuga.Tortuga: Representa una tortuga que se puede mover por la pantalla.
    - pilas.actores.zanahoria.Zanahoria: Representa un actor que parece una Zanahoria.
  - pilas.escena.escena_base.Base: Escena base abstracta de la que deben heredar el resto de escenas.
    - pilas.escena.escena_normal.Aviso: Escena básica de pilas.
    - pilas.escena.escena_normal.Normal: Escena básica de pilas.
    - pilas.demos.piezas.Piezas: Representa la escena de rompecabezas.
  - pilas.motores.motor_qt.BaseActor
  - pilas.camara.Camara: Representa el punto de vista de la ventana.
  - pilas.colores.Color: Representa un color en base a 4 componentes.
  - pilas.comportamientos.Comportamiento: Representa un comportamiento (estrategia) que se puede anexar a un actor.
    - pilas.comportamientos.Avanzar: Desplaza al actor en la dirección y sentido indicado por una rotación.
    - pilas.actores.pingu.Caminando: Representa al personaje caminando por el escenario.
    - pilas.actores.cooperativista.Caminando: Clase que define un comportamiento del actor Cooperativista.
    - pilas.actores.cooperativista.DecirOk: Clase que define un comportamiento del actor Cooperativista.
    - pilas.actores.martian.Disparar: Representa al actor disparando un proyectil.
    - pilas.actores.pingu.Esperando: Un actor en posicion normal o esperando a que el usuario pulse alguna tecla.
    - pilas.actores.cooperativista.Esperando: Clase que define un comportamiento del actor Cooperativista.
    - pilas.actores.personajes_rpg.Esperando: Un actor en posicion normal o esperando a que el usuario pulse alguna tecla.
      - pilas.actores.personajes_rpg.Caminando: Representa al personaje caminando por el escenario.
    - pilas.actores.martian.Esperando: Representa al actor en posicion normal.
      - pilas.actores.martian.Caminando: Representa al actor caminando hacia la izquierda o derecha.
    - pilas.comportamientos.Girar: Hace girar constantemente al actor respecto de su eje de forma relativa.
    - pilas.comportamientos.Proyectil: Hace que un actor se comporte como un proyectil.
    - pilas.actores.pingu.Saltando: Representa al actor saltando con animación.
    - pilas.actores.martian.Saltando: Representa al actor realizando un salto.
    - pilas.comportamientos.Saltar: Realiza un salto, cambiando los atributos 'y'.
  - pilas.control.Control: Representa un control de teclado sencillo.
  - pilas.depurador.DepuradorDeshabilitado
    - pilas.depurador.Depurador: Esta clase permite hacer depuraciones visuales.
  - pilas.escenas.Escena: Escena abstracta.
    - pilas.escenas.Normal: Representa la escena inicial mas simple.
  - pilas.fps.FPS: Representa un controlador de tiempo para el mainloop de pilas.
  - pilas.fisica.Figura: Representa un figura que simula un cuerpo fisico.
    - pilas.fisica.Circulo: Representa un cuerpo de circulo.
    - pilas.fisica.Poligono: Representa un cuerpo poligonal.
    - pilas.fisica.Rectangulo: Representa un rectángulo que puede colisionar con otras figuras.
  - pilas.fisica.Fisica: Representa un simulador de mundo fisico, usando la biblioteca Box2D (version 2.1).
  - pilas.fisica.FisicaDeshabilitada: Representa a un motor de física que no realiza acciones, y solo se habilita si box2d no funciona en el equipo.
  - pilas.escena.gestor.Gestor: Clase que permite el control de las escenas en pilas.
  - pilas.habilidades.Habilidad: Representa una habilidad que un actor puede aprender.
    - pilas.habilidades.Arrastrable: Hace que un objeto se pueda arrastrar con el puntero del mouse.
    - pilas.habilidades.AumentarConRueda: Permite cambiar el tamaño de un actor usando la ruedita scroll del mouse.
    - pilas.habilidades.Disparar: Establece la habilidad de poder disparar un Actor o un objeto de tipo pilas.municion.Municion.
      - pilas.habilidades.DispararConClick: Establece la habilidad de poder disparar un Actor o un objeto de tipo pilas.municion.Municion pulsando el boton izquierdo del ratón.
    - pilas.habilidades.Imitar: Logra que el actor imite las propiedades de otro.
    - pilas.habilidades.MirarAlActor: "Hace que un actor rote para mirar hacia otro actor.
    - pilas.habilidades.MoverseConElTeclado: Hace que un actor cambie de posición con pulsar el teclado.
      - pilas.habilidades.MoverseComoCoche: Hace que un actor se mueva como un coche.
    - pilas.habilidades.PisaPlataformas: Enseña al actor a pisar plataformas físicas.
    - pilas.habilidades.PuedeExplotar: Hace que un actor se pueda hacer explotar invocando al metodo eliminar.
    - pilas.habilidades.RebotarComoCaja: Le indica al actor que rebote y colisiones como una caja cuadrada.
    - pilas.habilidades.RebotarComoPelota: Le indica al actor que rebote y colisiones como una pelota.
      - pilas.habilidades.ColisionableComoPelota: Le indica al actor que colisione como una pelota, pero que no rebote.
    - pilas.habilidades.RotarConMouse: "Hace que un actor rote con respecto a la posicion del mouse.
    - pilas.habilidades.SeMantieneEnPantalla: Se asegura de que el actor regrese a la pantalla si sale o que no salga en nigún momento de la pantalla.
    - pilas.habilidades.SeguirAlMouse: Hace que un actor siga la posición del mouse en todo momento.
    - pilas.habilidades.SeguirClicks: Hace que el actor se coloque la posición del cursor cuando se hace click.
    - pilas.habilidades.SiempreEnElCentro: Hace que un actor siempre esté en el centro de la camara y la desplace cuando el actor se desplaza.
  - pilas.motores.motor_qt.Imagen
  - pilas.interpolaciones.Interpolacion: Representa una interpolacion, que pasa por varios puntos clave.
    - pilas.interpolaciones.AceleracionGradual: Representa una interpolación con aceleración gradual.
    - pilas.interpolaciones.DesaceleracionGradual: Representa una interpolación con aceleración gradual.
    - pilas.interpolaciones.ElasticoFinal: Representa una interpolación con rebote.
    - pilas.interpolaciones.ElasticoInicial: Representa una interpolación con rebote.
    - pilas.interpolaciones.Lineal: Representa una interpolación lineal.
    - pilas.interpolaciones.ReboteFinal: Representa una interpolación con rebote.
    - pilas.interpolaciones.ReboteInicial: Representa una interpolación con rebote.
  - pilas.depurador.ModoDepurador
    - pilas.depurador.ModoArea
    - pilas.depurador.ModoFisica
    - pilas.depurador.ModoInformacionDeSistema
    - pilas.depurador.ModoPosicion
    - pilas.depurador.ModoPuntosDeControl
    - pilas.depurador.ModoRadiosDeColision
    - pilas.depurador.ModoWidgetLog
  - pilas.motores.motor_qt.Motor: Representa la ventana principal de pilas.
  - pilas.mundo.Mundo: Representa un objeto unico que mantiene en funcionamiento al motor.
  - pilas.municion.Municion: Clase base para representar un conjunto de proyectiles que pueden ser disparados mediante la habilidad de Disparar.
    - pilas.municion.BalaDoble: Munición que dispara 2 balas paralelas.
    - pilas.municion.BalasDoblesDesviadas: Munición que dispara 2 balas en angulos distintos.
    - pilas.municion.MisilDoble: Munición que dispara 2 misiles paralelos que aceleran poco a poco.
  - pilas.evento.ProxyEventos: Representa el objeto pilas.evento, que internamente delega todos los metodos conectados a la escena actual.
  - pilas.evento.ProxyFuncion: Representa a una función de repuesta pero usando una referencia débil.
  - pilas.estudiante.ProxyHabilidades: Implementa un intermediario con todas las habilidades del Actor.
  - pilas.evento.ProxyMetodo: Permite asociar funciones pero con referencias débiles, que no incrementan el contador de referencias.
  - pilas.tareas.Tarea
    - pilas.tareas.TareaCondicional: Representa una tarea similar a Tarea, pero que solo se ejecuta si El retorno de la función a ejecutar devuelve True.
  - pilas.tareas.Tareas: Contenedor de tareas a ejecutar por tiempo.
  - pilas.pytweener.Tween
  - pilas.pytweener.Tweener
  - pilas.asistente_base.Ui_AsistenteWindow
  - pilas.lanzador_base.Ui_Dialog
  - pilas.ejemplos.ui.Ui_Ejemplos
  - pilas.interprete_base.Ui_InterpreteDialog
  - pilas.interprete.VentanaInterprete
  - dict: dict() -> new empty dictionary dict(mapping) -> new dictionary initialized from a mapping object's (key, value) pairs dict(iterable) -> new dictionary initialized as if via: d = {} for k, v in iterable: d[k] = v dict(**kwargs) -> new dictionary initialized with the name=value pairs in the keyword argument list.
    - pilas.evento.AttrDict: Envoltorio para que el diccionario de eventos se pueda acceder usando como si tuviera attributos de objeto.
  - list: list() -> new empty list list(iterable) -> new list initialized from iterable's items
    - pilas.grupo.Grupo: Un grupo es un contenedor que funciona como una lista normal, pero mejorada.